@@ -12,7 +12,7 @@
 #include <spectrumparser.h>
 
 #include <QCoreApplication>
-#include <QDebug>
+#include "kalzium_debug.h"
 #include <QFile>
 #include <QFileInfo>
 #include <QGlobalStatic>
@@ -37,7 +37,6 @@ KalziumDataObject* KalziumDataObject::instance()
 }
 
 KalziumDataObject::KalziumDataObject()
-        : m_search(nullptr)
 {
     // reading elements
     ElementSaxParser * parser = new ElementSaxParser();
@@ -184,7 +183,7 @@ void KalziumDataObject::loadIconSet()
     //a settings-dialog where we can select the different iconsets...
     const QString setname = QStringLiteral("school");
     QString pathname = QStandardPaths::locate(
-        QStandardPaths::DataLocation, "data/iconsets/" + setname + '/',
+        QStandardPaths::AppLocalDataLocation, "data/iconsets/" + setname + '/',
         QStandardPaths::LocateDirectory);
     QSvgRenderer renderer;
 
